RapidPro Expressions
====================

Python implementation of the RapidPro expression and templating system

Usage
-----

```python
context = new EvaluationContext()
context.put_variable("name", "bob jones")

TemplateEvaluator evaluator = TemplateEvaluator()
output, errors = evaluator.evaluate_template("Hi @(PROPER(name))", context, False)

assert output == "Hi Bob Jones"
assert len(errors) == 0
```